package
Version:
v0.2.5
Opens a new window with list of versions in this module.
Published: Feb 18, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type In struct {
URL string `json:"url" is:"required" description:"The URL to fetch content from"`
}
type Out struct {
Status int `json:"status"`
Content string `json:"content"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.